# Django
from django.contrib import admin
from django.test import TestCase

# django_register
from tests.models import City


@admin.register(City)
class CityAdmin(admin.ModelAdmin):
    pass


class AdminTestCase(TestCase):
    @classmethod
    def setUpTestData(cls) -> None:
        cls.city = City.objects.create(label="Ottawa")

    def test_admin_choices(self):
        built_admin = CityAdmin(City, admin.site)

        # choices was renamed to _choices in Django 5.0
        choices = getattr(
            built_admin.opts._forward_fields_map["available_food"],
            "choices",
        ) or getattr(
            built_admin.opts._forward_fields_map["available_food"], "_choices", None
        )
        self.assertEqual(
            choices,
            [("pizza", "Pizza")],
        )



# Future
from __future__ import annotations

# Standard libraries
import os

BASE_DIR = os.path.dirname(os.path.dirname(__file__))

SECRET_KEY = "NOTASECRET"

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": "test_db.sqlite",
        "ATOMIC_REQUESTS": True,
    },
}

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.contenttypes",
    "django.contrib.auth",
    "django.contrib.messages",
    "tests",
]


MIDDLEWARE = [
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
]


TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    }
]

USE_TZ = True



# Django
from django.test import TestCase

# django_register
from tests.models import CountryChoices


class ChoicesTestCase(TestCase):
    def test_iter(self):
        for klass in CountryChoices:
            self.assertIn(klass, CountryChoices)

    def test_choices(self):
        self.assertEqual(
            CountryChoices.choices,
            [
                ("canada", "Canada"),
                ("france", "France"),
                ("germany", "Germany"),
                ("united_states", "United States"),
            ],
        )

    def test_build_choice(self):
        self.assertEqual(CountryChoices("canada"), CountryChoices.CANADA)
        self.assertEqual(CountryChoices(CountryChoices.CANADA), CountryChoices.CANADA)
